'use strict'

const {prompt} = require('inquirer');
const {writeFile} = require('fs');
const {error} = require('./logger');
const utils = require('./utils');
const listTable = utils.listTable;
let tplList = utils.tplList;

/**
 * getQuestion: 获取命令行输入属性
 * @param  {string} options add命令所带属性值
 * @return {array} 属性列表
 */
const getQuestion = (options) => {
  return [
    {
      type: 'input',
      name: 'templateName',
      message: '新增的模板名:',
      default: typeof(options.name) === 'string'
        ? options.name
        : '',
      validate(val) {
        if (tplList[val]) {
          return '模板已存在!'
        } else if (val === '') {
          return '模板名不能为空!'
        } else {
          return true
        }
      }
    }, {
      type: 'input',
      name: 'repositorieOwnerName',
      message: '模板的创建者（github用户名）:',
      default: typeof(options.user) === 'string'
        ? options.user
        : '',
      validate(val) {
        if (val !== '') {
          return true
        }
        return '创建者不能为空!'
      }
    }, {
      type: 'input',
      name: 'repositorie',
      message: '模板对应github库名（repositorie名）:',
      default: typeof(options.rep) === 'string'
        ? options.rep
        : '',
      validate(val) {
        if (val !== '') {
          return true
        }
        return 'github库名不能为空!'
      }
    }, {
      type: 'input',
      name: 'branch',
      message: 'github库的分支信息（默认为master）:',
      default: typeof(options.branch) === 'string'
        ? options.branch
        : 'master'
    }
  ]
};
/**
 * delCli add命令处理
 * @param  {string} options add命令所带属性值
 */
const addCli = (options) => {
  const question = getQuestion(options);
  prompt(question).then(({templateName, repositorieOwnerName, repositorie, branch}) => {
    tplList[templateName] = {
      repositorieOwnerName,
      repositorie,
      branch
    }
    writeFile(`${__dirname}/../templates.json`, JSON.stringify(tplList), 'utf-8', (err) => {
      if (err) {
        error(err);
        process.exit();
      }
      listTable(tplList, 'New template has been added successfully!');
    })
  })
}

module.exports = addCli;
