'use strict'

const {prompt} = require('inquirer');
const download = require('download-git-repo');
const ora = require('ora');
const {error, success} = require('./logger');
let {tplList} = require('./utils');

const getQuestion = (options) => {
  return [
    {
      type: 'input',
      name: 'project_name',
      message: '要创建的工程名:',
      default: typeof(options.pname) === 'string'
        ? options.pname
        : '',
      validate(val) {
        if (val !== '') {
          return true
        }
        return 'Project name is required!'
      }
    }, {
      type: 'input',
      name: 'template_name',
      message: '输入选择的模板名:',
      default: typeof(options.tname) === 'string'
        ? options.tname
        : '',
      validate(val) {
        if (tplList[val]) {
          return true;
        } else {
          return '该模板不存在!';
        }
      }
    }, {
      type: 'input',
      name: 'project_position',
      message: '工程相对地址:',
      default: typeof(options.dir) === 'string'
        ? options.dir
        : './'
    }
  ]
};
const create = (options) => {
  if ((Object.keys(tplList)).length == 0) {
    error('模板列表为空，无法创建工程，请先添加模板');
    process.exit();
  }
  const question = getQuestion(options);
  prompt(question).then(({template_name, project_name, project_position}) => {
    const gitOwner = tplList[template_name]['repositorieOwnerName']
    const gitRepositories = tplList[template_name]['repositorie']
    const gitBranch = tplList[template_name]['branch']
    const proPos = `${project_position}/${project_name}`;
    const gitPlace = `${gitOwner}/${gitRepositories}`
    const gitUrl = `${gitPlace}#${gitBranch}`;

    const loading = ora('Downloading...');
    loading.start();
    download(gitUrl, proPos, (err) => {
      if (err) {
        error(err);
        process.exit();
      }
      loading.stop();
      success('New project has been initialized successfully!');
    })
  })
}
module.exports = create;
